
from setuptools import setup

setup(name='pip_model',
      version='0.6',
      description='string to date',
      url="https://github.com/18832823200/pip_model",
      aauthor="sbdsyf",
      author_email="zkw8119@163.com",
      license='MIT',
      packages=['pip_model'],
      include_package_data=True,
      platforms="any",
      install_requires=[]
      )
